@@ -184,6 +184,7 @@
 ( "file_type_falcon", 0xf15b ),
 ( "file_type_favicon", 0xe623 ), // 
 ( "file_type_fbx", 0xf15b ),
+( "file_type_fennel", 0xe6af ), // 
 ( "file_type_firebase", 0xf0967 ), // 󰥧
 ( "file_type_firebasehosting", 0xe787 ), // 
 ( "file_type_firestore", 0xe657 ), // 
@@ -542,7 +543,7 @@
 ( "file_type_pddl_happenings", 0xf1b5 ), //
 ( "file_type_pddl_plan", 0xf15b ),
 ( "file_type_pdf", 0xeaeb ), // 
-( "file_type_pdf2", 0xf15b ),
+( "file_type_pdf2", 0xe67d ), // 
 ( "file_type_perl", 0xe769 ), // 
 ( "file_type_perl2", 0xe769 ),
 ( "file_type_perl6", 0xe769 ),
