@@ -4,7 +4,10 @@ use {
         errors::ProgramError,
     },
     std::{
-        fs::{File, OpenOptions},
+        fs::{
+            File,
+            OpenOptions,
+        },
         io::Write,
     },
 };
@@ -19,10 +22,7 @@ pub fn verb_write(
     let Some(path) = &con.launch_args.verb_output else {
         return Ok(CmdResult::error("No --verb-output provided".to_string()));
     };
-    let mut file = OpenOptions::new()
-        .create(true)
-        .append(true)
-        .open(path)?;
+    let mut file = OpenOptions::new().create(true).append(true).open(path)?;
     if file.metadata().map(|m| m.len() > 0).unwrap_or(false) {
         writeln!(file)?;
     }
@@ -31,9 +31,7 @@ pub fn verb_write(
 }
 
 /// Remove the content of the file provided to broot with `--verb-output`.
-pub fn verb_clear_output(
-    con: &AppContext,
-) -> Result<CmdResult, ProgramError> {
+pub fn verb_clear_output(con: &AppContext) -> Result<CmdResult, ProgramError> {
     let Some(path) = &con.launch_args.verb_output else {
         return Ok(CmdResult::error("No --verb-output provided".to_string()));
     };
